herosdevices.hardware.saes.nextorr - Heros Devices 0.6.0 documentation

Skip to content
Back to top
View this page

# herosdevices.hardware.saes.nextorr

Device driver for SAES NEXTorr non-evaporative getter/sputter ion pump controller NIOPS.

## Module Contents

class herosdevices.hardware.saes.nextorr.NEXTorr(device: str, baudrate: int = 115200)

  Bases: `herosdevices.core.templates.SerialDeviceTemplate`

  A NEXTorr vacuum pump with serial based connection.

  pressure
  voltage
  current
  version
  ion_pump_on() → bool

    Turn the integrated sputter ion pump on.

  ion_pump_off() → bool

    Turn the integrated sputter ion pump off.

  ion_pump_set_voltage(voltage: int) → bool

    Set the integrated sputter ion pump voltage.

    Parameters:

      voltage – Voltage in V

  address
  connection